from distutils.core import setup

setup(
  name = 'shaonutil',
  packages = ['shaonutil'],
  version = '0.0.0.1.1',
  description = 'collection of utility by shaon',
  author = 'Shaon Majumder',
  author_email = 'smazoomder@gmail.com',
  url = 'https://github.com/ShaonMajumder/shaonutil',
  download_url = 'https://github.com/ShaonMajumder/shaonutil/archive/0.0.0.1.1.tar.gz',
  keywords = ['shaon', 'utility', 'statistics'], 
  classifiers = [],
)